@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
 
 from FADiff import FADiff
-from fad.Gradients import Scal as fadScal
-from fad.Matrices import Vect as fadVect
-from rev.Gradients import Scal as revScal
-from rev.Matrices import Vect as revVect
+from FADiff.fad.Gradients import Scal as fadScal
+from FADiff.fad.Matrices import Vect as fadVect
+from FADiff.rev.Gradients import Scal as revScal
+from FADiff.rev.Matrices import Vect as revVect
 import numpy as np
 
 
